[hipl-commit] [tiny] Rev 3622: Renamed hip_create_i2 to hip_send_i2 by reason of consistency.

  • From: Tim Just <tim.just@xxxxxxxxxxxxxx>
  • To: hipl-commit@xxxxxxxxxxxxx
  • Date: Fri, 5 Mar 2010 12:28:32 +0200

Committer: Tim Just <tim.just@xxxxxxxxxxxxxx>
Date: Fri Mar 05 11:27:01 2010 +0100
Revision: 3622
Revision-id: tim.just@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
Branch nick: tiny

Log:
  Renamed hip_create_i2 to hip_send_i2 by reason of consistency.

Modified:
  M  hipd/input.c
  M  hipd/input.h

=== modified file 'hipd/input.c'
--- hipd/input.h        2010-03-05 10:06:35 +0000
+++ hipd/input.h        2010-03-05 10:27:01 +0000
@@ -116,7 +116,7 @@
 int hip_produce_keying_material(struct hip_common *msg, struct hip_context 
*ctx,
                                 uint64_t I, uint64_t J, struct 
hip_dh_public_value **dhpv);
 
-int hip_create_i2(struct hip_context *ctx, uint64_t solved_puzzle,
+int hip_send_i2(struct hip_context *ctx, uint64_t solved_puzzle,
                   in6_addr_t *r1_saddr, in6_addr_t *r1_daddr, hip_ha_t *entry,
                   hip_portpair_t *r1_info, struct hip_dh_public_value *dhpv);

Other related posts:

  • » [hipl-commit] [tiny] Rev 3622: Renamed hip_create_i2 to hip_send_i2 by reason of consistency. - Tim Just
--- hipd/input.c        2010-03-05 10:21:10 +0000
+++ hipd/input.c        2010-03-05 10:27:01 +0000
@@ -707,7 +707,7 @@
  *
  * @return zero on success, non-negative on error.
  */
-int hip_create_i2(struct hip_context *ctx, uint64_t solved_puzzle,
+int hip_send_i2(struct hip_context *ctx, uint64_t solved_puzzle,
                   in6_addr_t *r1_saddr, in6_addr_t *r1_daddr, hip_ha_t *entry,
                   hip_portpair_t *r1_info, struct hip_dh_public_value *dhpv)
 {
@@ -1050,7 +1050,7 @@
 /**
  * Handles an incoming R1 packet.
  *
  * Handles an incoming R1 packet and calls hip_create_i2() if the R1 packet
  * passes all tests.
  *
  * @param r1       a pointer to the received R1 HIP packet common header with
@@ -1257,11 +1257,11 @@
 
     /******************************************************************/
 
     /* We haven't handled REG_INFO parameter. We do that in hip_create_i2()
      * because we must create an REG_REQUEST parameter based on the data
      * of the REG_INFO parameter. */
 
-    err = hip_create_i2(ctx,
+    err = hip_send_i2(ctx,
                         solved_puzzle,
                         packet_ctx->src_addr,
                         packet_ctx->dst_addr,
@@ -2045,7 +2045,7 @@
     }
     //end add
 
-    // moved from hip_create_i2
+    // moved from hip_send_i2
     HIP_DEBUG_HIT("hit our", &(packet_ctx->hadb_entry)->hit_our);
     HIP_DEBUG_HIT("hit peer", &(packet_ctx->hadb_entry)->hit_peer);
     HIP_IFEL(hip_add_sa(packet_ctx->src_addr,
@@ -1050,7 +1050,7 @@
  * Handles an incoming R1 packet.
  *
- * Handles an incoming R1 packet and calls hip_create_i2() if the R1 packet
+ * Handles an incoming R1 packet and calls hip_send_i2() if the R1 packet
  * passes all tests.
  *
@@ -1257,11 +1257,11 @@
     /******************************************************************/
 
-    /* We haven't handled REG_INFO parameter. We do that in hip_create_i2()
+    /* We haven't handled REG_INFO parameter. We do that in hip_send_i2()
      * because we must create an REG_REQUEST parameter based on the data
      * of the REG_INFO parameter. */

=== modified file 'hipd/input.h'